#
# Conditional build:
%bcond_without	systemd		# systemd
%bcond_without	nfacct		# build with nfacct plugin

%define release_suffix .32ef8897

%if 0%{?fedora} || 0%{?rhel} >= 7
%else
%undefine	with_systemd
%undefine	with_nfacct
%endif

Summary:	Real-time performance monitoring, done right
Name:		netdata
Version:	1.2.1
Release:	1%{?release_suffix}%{?dist}
Epoch:		1
License:	GPL v3+
Group:		Applications/System
Source0:	http://firehol.org/download/netdata/releases/v1.2.1/%{name}-1.2.1%{?release_suffix}.tar.xz
Source1:	version.txt
Source2:	netdata.conf
URL:		http://netdata.firehol.org/
BuildRequires:	pkgconfig
BuildRequires:	xz
BuildRequires:	zlib-devel
%if %{with nfacct}
BuildRequires:	libmnl-devel
BuildRequires:	libnetfilter_acct-devel
%endif
%if %{with systemd}
BuildRequires:		systemd
Requires(post):		systemd
Requires(preun):	systemd
Requires(postun):	systemd
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
netdata is the fastest way to visualize metrics. It is a resource
efficient, highly optimized system for collecting and visualizing any
type of realtime timeseries data, from CPU usage, disk activity, SQL
queries, API calls, web site visitors, etc.

netdata tries to visualize the truth of now, in its greatest detail,
so that you can get insights of what is happening now and what just
happened, on your systems and applications.

%prep
%setup -q -n %{name}-1.2.1
sh ./autogen.sh

%build
%configure \
	--docdir=%{_docdir}/%{name}-%{version} \
	--with-zlib \
	--with-math \
	%{?with_nfacct:--enable-plugin-nfacct} \
	--with-user=netdata
%{__make} %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} %{?_smp_mflags} install \
	DESTDIR=$RPM_BUILD_ROOT

install -m 644 -p system/netdata.conf $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/

find $RPM_BUILD_ROOT -name .keep | xargs rm

%if %{with systemd}
install -d $RPM_BUILD_ROOT%{_unitdir}
install -m 644 -p system/netdata.service $RPM_BUILD_ROOT%{_unitdir}/netdata.service
%else
install -d $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d
install -m 755 system/netdata-init-d $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/netdata
%endif

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/netdata

install -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_datadir}/%{name}/web/version.txt
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/netdata.conf

%pre
getent group netdata > /dev/null || groupadd -r netdata
getent passwd netdata > /dev/null || useradd -r -g netdata -c netdata -s /sbin/nologin -d / netdata

%if %{with systemd}
%post
%systemd_post netdata.service

%preun
%systemd_preun netdata.service

%postun
%systemd_postun_with_restart netdata.service
%else
%post
if [ $1 = 1 ]; then
	/sbin/chkconfig --add %{name}
	/sbin/chkconfig --level 35 %{name} on
fi

%preun
if [ $1 = 0 ]; then
	/sbin/service %{name} stop > /dev/null 2>&1
	/sbin/chkconfig --del %{name}
fi
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%attr(-,netdata,netdata) %dir %{_localstatedir}/cache/%{name}
%attr(-,netdata,netdata) %dir %{_localstatedir}/log/%{name}
%attr(-,netdata,netdata) %dir %{_localstatedir}/lib/%{name}
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/%{name}/*.conf
%dir %{_sysconfdir}/%{name}
%{?with_systemd:%{_unitdir}/netdata.service}
%{?!with_systemd:%{_sysconfdir}/rc.d/init.d/netdata}
%{_libexecdir}/%{name}
%{_sbindir}/%{name}
%dir %{_datadir}/%{name}

# override defattr for web files
%defattr(644,root,netdata,755)
%{_datadir}/%{name}/web

%changelog
* Fri Jun 10 2016 JoungKyun.Kim <http://oops.org> - 1.2.1-1%{?release_suffix}%{?dist}
- update 1.2.1-master 32ef889745cc281ffb96d56f384bdee1e598b64d

* Mon May 16 2016 Costa Tsaousis <costa@tsaousis.gr> - 1.2.0-1
- netdata is now 30% faster.
- netdata now has a registry (my-netdata menu on the dashboard).
- netdata now monitors Linux containers.
- Several more improvements, new features and bugfixes.
* Wed Apr 20 2016 Costa Tsaousis <costa@tsaousis.gr> - 1.1.0-1
- Several new features (IPv6, SYNPROXY, Users, Users Groups).
- A lot of bug fixes and optimizations.
* Tue Mar 22 2016 Costa Tsaousis <costa@tsaousis.gr> - 1.0.0-1
- First public release.
* Sun Nov 15 2015 Alon Bar-Lev <alonbl@redhat.com> - 0.0.0-1
- Initial add.
